==> blue2-theme-neilson-recruitment-1.0.16-461b77.tar: templates/parts/site-footer.php <==
<footer class="site-footer">
    <div class="container-fluid site-padding">
        <div class="row">
            <div class="col-md-12">
                <div class="footer-newsletter">
                    <div class="row">
                        <div class="col-sm-12 col-lg-4">
                            <?= get_field('footer_newsletter_text', 'options'); ?>
                        </div>
                        <div class="col-lg-8 newsletter-form">
                            <form action="https://neilsonrecruitment.us5.list-manage.com/subscribe/post?u=a2b6342c53858c9881db6e1ba&amp;id=8d12c2dfa0" method="post" id="mc-embedded-subscribe-form" name="mc-embedded-subscribe-form" class="validate" target="_blank" novalidate>
                                <div class="row">
                                    <div class="col-sm-12 col-lg-4">
                                        <input type="text" name="FNAME" id="mce-FNAME" class="form-control" placeholder="Full name...">
                                    </div>
                                    <div class="col-sm-12 col-lg-4">
                                        <input type="email" name="EMAIL" id="mce-EMAIL" class="form-control" placeholder="Email Address...">
                                    </div>
                                    <div class="col-5 d-lg-none"></div>
                                    <div class="col-7 col-lg-4">
                                        <button type="submit" class="btn btn-primary newsletter-btn">Submit <i class="fas fa-arrow-right"></i></button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="row main-footer-section">
            <div class="col-6 col-md-4">
                <a class="footer-logo" href="<?php echo esc_url(home_url('/')); ?>">
                    <img src="<?= get_field('footer_logo', 'options'); ?>" alt="<?php bloginfo('name'); ?>" />
                </a>
            </div>
            <div class="col-6 col-md-8">
                <div class="row">
                    <div class="col-md-12">
                        <ul class="social-media-list">
                            <?php while( have_rows('social_media_channels', 'options') ) : the_row(); ?>
                                <a href="<?=get_sub_field('full_url');?>" target="_blank"><li><i class="<?= get_sub_field('fa5_icon_class'); ?>"></i></li></a>
                            <?php endwhile; ?>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="col-12 d-none d-lg-block footer-menu">
                <?php 
                    wp_nav_menu(
                        array( 'menu' => 'footer-menu' 
                    )); 
                ?>
            </div>
        </div>
        <div class="row">
            <div class="col-md-6 d-lg-none">
                <div class="row">
                    <div class="col-md-6">
                        <div class="footer-small-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'drop-down-menu-left' 
                                )); 
                            ?>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="footer-small-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'drop-down-menu-right' 
                                )); 
                            ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-sm-6 footer-address">
                <?= get_field('footer_address', 'options'); ?>
            </div>
            <div class="col-sm-6 site-by-flex">
                <div class="site-by">
                    <p class="d-inline-block">Site by</p>
                    <img class="d-inline-block" src="<?= get_field('blue2_logo', 'options'); ?>" alt="">
                </div>
            </div>
        </div>
    </div>
</footer>

==> blue2-theme-neilson-recruitment-1.0.24-4415b4.tar: templates/parts/site-footer.php <==
<footer class="site-footer">
    <div class="container-fluid site-padding">
        <div class="row">
            <div class="col-md-12">
                <div class="footer-newsletter">
                    <div class="row">
                        <div class="col-sm-12 col-lg-4">
                            <?= get_field('footer_newsletter_text', 'options'); ?>
                        </div>
                        <div class="col-lg-8 newsletter-form">
                            <form action="https://neilsonrecruitment.us5.list-manage.com/subscribe/post?u=a2b6342c53858c9881db6e1ba&amp;id=8d12c2dfa0" method="post" id="mc-embedded-subscribe-form" name="mc-embedded-subscribe-form" class="validate" target="_blank" novalidate>
                                <div class="row">
                                    <div class="col-sm-12 col-lg-4">
                                        <input type="text" name="FNAME" id="mce-FNAME" class="form-control" placeholder="Full name...">
                                    </div>
                                    <div class="col-sm-12 col-lg-4">
                                        <input type="email" name="EMAIL" id="mce-EMAIL" class="form-control" placeholder="Email Address...">
                                    </div>
                                    <div class="col-5 d-lg-none"></div>
                                    <div class="col-7 col-lg-4">
                                        <button type="submit" class="btn btn-primary newsletter-btn">Submit <i class="fas fa-arrow-right"></i></button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="row main-footer-section">
            <div class="col-6 col-md-4">
                <a class="footer-logo" href="<?php echo esc_url(home_url('/')); ?>">
                    <img src="<?= get_field('footer_logo', 'options'); ?>" alt="<?php bloginfo('name'); ?>" />
                </a>
            </div>
            <div class="col-6 col-md-8">
                <div class="row">
                    <div class="col-md-12">
                        <ul class="social-media-list">
                            <?php while( have_rows('social_media_channels', 'options') ) : the_row(); ?>
                                <a href="<?=get_sub_field('full_url');?>" target="_blank"><li><i class="<?= get_sub_field('fa5_icon_class'); ?>"></i></li></a>
                            <?php endwhile; ?>
                        </ul>
                    </div>
                </div>
            </div>
            <div class="col-12 d-none d-lg-block footer-menu">
                <?php 
                    wp_nav_menu(
                        array( 'menu' => 'footer-menu' 
                    )); 
                ?>
            </div>
        </div>
        <div class="row">
            <div class="col-md-6 d-lg-none">
                <div class="row">
                    <div class="col-sm-3 col-md-6">
                        <div class="footer-small-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'drop-down-menu-left' 
                                )); 
                            ?>
                        </div>
                    </div>
                    <div class="col-sm-3 col-md-6">
                        <div class="footer-small-menu">
                            <?php 
                                wp_nav_menu(
                                    array( 'menu' => 'drop-down-menu-right' 
                                )); 
                            ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-sm-6 footer-address">
                <?= get_field('footer_address', 'options'); ?>
            </div>
            <div class="col-sm-6 site-by-flex">
                <div class="site-by">
                    <p class="d-inline-block">Site by</p>
                    <a href="https://blue2.co.uk/"><img class="d-inline-block" src="<?= get_field('blue2_logo', 'options'); ?>" alt=""></a>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-12">
                <div class="text-xs-center text-md-right footer-small-menu mt-3">
                    <?php 
                        wp_nav_menu(
                            array( 'menu' => 'Policy Menu' 
                        )); 
                    ?>
                </div>
            </div>
        </div>
    </div>
</footer>
